@@ -159,10 +159,13 @@ ENCAtlas::~ENCAtlas()
 }
 
 void ENCAtlas::load(const Projection &in, const Projection &out,
-  qreal deviceRatio, bool hidpi)
+  qreal deviceRatio, bool hidpi, bool hillShading, int style, int layer)
 {
 	Q_UNUSED(in);
 	Q_UNUSED(hidpi);
+	Q_UNUSED(hillShading);
+	Q_UNUSED(style);
+	Q_UNUSED(layer);
 
 	_tileRatio = deviceRatio;
 	_projection = out;
